package com.cpms.project.safety.service.impl;

import com.cpms.project.safety.domain.TSafetyFiredoor;
import com.cpms.project.safety.mapper.TSafetyFiredoorMapper;
import com.cpms.project.safety.service.ITSafetyFiredoorService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 防火门Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-05-31
 */
@Service
public class TSafetyFiredoorServiceImpl implements ITSafetyFiredoorService
{
    @Autowired
    private TSafetyFiredoorMapper tSafetyFiredoorMapper;

    /**
     * 查询防火门
     * 
     * @param id 防火门主键
     * @return 防火门
     */
    @Override
    public TSafetyFiredoor selectTSafetyFiredoorById(Long id)
    {
        return tSafetyFiredoorMapper.selectTSafetyFiredoorById(id);
    }

    /**
     * 查询防火门列表
     * 
     * @param tSafetyFiredoor 防火门
     * @return 防火门
     */
    @Override
    public List<TSafetyFiredoor> selectTSafetyFiredoorList(TSafetyFiredoor tSafetyFiredoor)
    {
        return tSafetyFiredoorMapper.selectTSafetyFiredoorList(tSafetyFiredoor);
    }

    /**
     * 新增防火门
     * 
     * @param tSafetyFiredoor 防火门
     * @return 结果
     */
    @Override
    public int insertTSafetyFiredoor(TSafetyFiredoor tSafetyFiredoor)
    {
        return tSafetyFiredoorMapper.insertTSafetyFiredoor(tSafetyFiredoor);
    }

    /**
     * 修改防火门
     * 
     * @param tSafetyFiredoor 防火门
     * @return 结果
     */
    @Override
    public int updateTSafetyFiredoor(TSafetyFiredoor tSafetyFiredoor)
    {
        return tSafetyFiredoorMapper.updateTSafetyFiredoor(tSafetyFiredoor);
    }

    /**
     * 批量删除防火门
     * 
     * @param ids 需要删除的防火门主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyFiredoorByIds(Long[] ids)
    {
        return tSafetyFiredoorMapper.deleteTSafetyFiredoorByIds(ids);
    }

    /**
     * 删除防火门信息
     * 
     * @param id 防火门主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyFiredoorById(Long id)
    {
        return tSafetyFiredoorMapper.deleteTSafetyFiredoorById(id);
    }
}
